function [alpha0, beta0] = rpsa_init_eigval(A, B, epsln)
%   Compute initial (rectangular) `eigenvalue' of A, B
%   lying in the real epsln-pseudospectrum.

%   Revised: Jun. 13, 2016.

n = size(A,1); 
k = size(A,2);

if isequal(B(1:k,:), eye(k)) % standard eigenvalue problem
    e = eig(A(1:k,:));
else    % generalized  eigenvalue
    e = eig(A(1:k,:), B(1:k,:)); 
end

if n > k % non-square case, check residual condition
    for ii = 1:k
        ee = e(ii);
        s = svd(A - ee * B);
        if s(end) > epsln, e(ii) = inf; end
    end
    e(e == inf) = []; % remove undesired eigvals
end

% compute largest real eig
[~,idx] = max(real(e)); 
e = e(idx);
alpha0 = real(e);  
beta0 = imag(e);

return
% END

