function v = rpsas_expand_eigvec(A0, u, v, epsln, neigs)
%   Auxiliary function to generate expanding vector in rpsas
%   using dynamical low-rank acceleration.

%   Revised: Jun. 13, 2016.

opts.maxit = 1000;

% Generate low-rank perturbation matrix
v = reshape(v, length(A0),[]);
u = reshape(u, length(A0),[]);
[UU2,~,VV2] = svd(u,0); UU = UU2 * VV2';
[UU2,~,VV2] = svd(v,0); VV = UU2 * VV2';
DA = epsln * UU * VV';

% Compute rightmost eigenvector
[VV, SS] = eigs(A0 - DA, neigs, 'LR', opts);
SS = diag(SS); SS(isnan(SS)) = -inf;
[~,idx] = max(real(SS)); 
VV = VV(:,idx);
v = [real(VV),imag(VV)];

return
% END

