function [V, e0, message] = rpsas_init_subspace(A0, neig)
%   Compute the initial projection subspace V, and
%   rightmost eigenvalue e0.

%   Revised: Jun. 13, 2016.

opts.maxit = 1000;
try 
    [V0, E0] = eigs(A0, neig, 'LR', opts);
catch exception
    message = exception.message;
    V = [];
    e0 = [];
    return
end

E = diag(E0); 
E(isnan(E)) = -inf; % in case of NaN eigvals
[~,idx] = sort(real(E), 'descend');

if isempty(E)
    message = 'rightmost eigenvalue not found!';
    V = [];
    e0 = [];
    return;
end

e0 = E( idx(1) ); % eig of largest real part
if imag(e0) == 0 % real eigenvector 
    V = V0(:,idx(1:2));
    [V,~] = qr(V, 0); 
else
    V = V0(:,idx(1));
    [V,~] = qr([real(V),imag(V)], 0); 
end
message = [];

return;
